//  
//   Rebex Sample Code License
// 
//   Copyright 2024, REBEX CR s.r.o.
//   All rights reserved.
//   https://www.rebex.net/
// 
//   Permission to use, copy, modify, and/or distribute this software for any
//   purpose with or without fee is hereby granted.
// 
//   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
//   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//   OTHER DEALINGS IN THE SOFTWARE.
// 

using System;
using Rebex.Net;

namespace Rebex.Samples
{
    /// <summary>
    /// This sample asks a time server for time and displays its answer.
    /// </summary>
    class TimeGetter
    {
        [STAThread]
        static void Main(string[] args)
        {
            // set the trial license key
            Rebex.Licensing.Key = Rebex.Samples.TrialKey.Key;


            if (args.Length != 1)
            {
                Console.WriteLine("Usage: TimeGetter server.name");
                Console.WriteLine("Example: TimeGetter test.rebex.net");
                return;
            }

            Ntp ntp = new Ntp(args[0]);

            // since we want to know the highest version the server supports, we 
            // must declare the highest ourselves (otherwise it would use 
            // compatibility mode)
            ntp.VersionNumber = 4;

            NtpResponse response = ntp.GetTime();
            NtpPacket packet = response.Packet;

            Console.WriteLine(
                "We sent the request to the server at {0} UTC and received its response at {1} UTC.", 
                packet.OriginateTimestamp, 
                packet.DestinationTimestamp
            );
            
            Console.WriteLine(
                "The server at {0} has stratum {1} and runs NTP version {2}.",
                args[0],
                packet.Stratum,
                packet.VersionNumber
            );
                
            Console.WriteLine(
                "It received our request at {0} UTC and responded to it at {1} UTC.",
                packet.ReceiveTimestamp,
                packet.TransmitTimestamp
            );
                
            Console.WriteLine("");
            
            DateTime current = DateTime.Now;
            DateTime exact = current + response.TimeOffset.ToTimeSpan();
            Console.WriteLine(
                "The current local time is {0} and it should be adjusted to {1}.", 
                current, 
                exact
            );
        }
    }
}
