//  
//   Rebex Sample Code License
// 
//   Copyright 2024, REBEX CR s.r.o.
//   All rights reserved.
//   https://www.rebex.net/
// 
//   Permission to use, copy, modify, and/or distribute this software for any
//   purpose with or without fee is hereby granted.
// 
//   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
//   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//   OTHER DEALINGS IN THE SOFTWARE.
// 

using System;
using Rebex.Net;
using Rebex;

namespace Rebex.Samples
{
    /// <summary>
    /// This sample asks a time server for time and uses the answer to update time
    /// on the local machine.
    /// </summary>
    class Synchronize
    {
        [STAThread]
        static void Main(string[] args)
        {
            // set the trial license key
            Rebex.Licensing.Key = Rebex.Samples.TrialKey.Key;


            if (args.Length != 1)
            {
                Console.WriteLine("Usage: TimeSynchronize server.name");
                Console.WriteLine("Example: TimeSynchronize test.rebex.net");
                return;
            }

            Console.WriteLine("Local time is {0}.", DateTime.Now);
            
            // get NTP server response
            Ntp client = new Ntp(args[0]);
            NtpResponse response = client.GetTime();
            
            // show the time offset received
            Console.WriteLine("Moving local time by {0}.", response.TimeOffset.ToTimeSpan());
            
            // adjust local time
            SystemClock.AdjustClock(response);

            Console.WriteLine("Corrected local time is {0}.", DateTime.Now);
        }
    }
}
